package com.example.vaadinform;

import javax.servlet.annotation.WebServlet;

import com.vaadin.annotations.Theme;
import com.vaadin.annotations.VaadinServletConfiguration;
import com.vaadin.data.Validator.InvalidValueException;
import com.vaadin.data.fieldgroup.FieldGroup;
import com.vaadin.data.util.ObjectProperty;
import com.vaadin.data.util.PropertysetItem;
import com.vaadin.data.validator.EmailValidator;
import com.vaadin.data.validator.IntegerRangeValidator;
import com.vaadin.data.validator.StringLengthValidator;
import com.vaadin.server.FontAwesome;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinServlet;
import com.vaadin.ui.Button;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.FormLayout;
import com.vaadin.ui.Label;
import com.vaadin.ui.Notification;
import com.vaadin.ui.TextField;
import com.vaadin.ui.UI;

@SuppressWarnings("serial")
@Theme("vaadinform")
public class VaadinformUI extends UI {

	@WebServlet(value = "/*", asyncSupported = true)
	@VaadinServletConfiguration(productionMode = false, ui = VaadinformUI.class)
	public static class Servlet extends VaadinServlet {
	}

	@Override
	protected void init(VaadinRequest request) 
	  {
	    final FormLayout layout = new FormLayout();
	    layout.setMargin(true);
	    setContent(layout);

	    PropertysetItem myfields = new PropertysetItem();
	    myfields.addItemProperty("name", new ObjectProperty<String>(""));
	    myfields.addItemProperty("age", new ObjectProperty<Integer>(0));
	    myfields.addItemProperty("email", new ObjectProperty<String>(""));

	    Label errLabel = new Label();

	    TextField nameText = new TextField("Name");
	    nameText.setValidationVisible(false);
	    nameText.setIcon(FontAwesome.AMBULANCE);
	    StringLengthValidator slv = new StringLengthValidator("The name must be 3-10 letters (was {0})", 3, 10, true);
	    nameText.addValidator(slv);
	    layout.addComponent(nameText);

	    TextField ageText = new TextField("Age");
	    ageText.setValidationVisible(false);
	    IntegerRangeValidator ir = new IntegerRangeValidator("Age must be between 21 and 30", 21, 30);
	    ageText.addValidator(ir);
	    layout.addComponent(ageText);

	    TextField emailText = new TextField("email");
	    emailText.setValidationVisible(true);
	    emailText.setRequired(true);
	    EmailValidator ev = new EmailValidator("You must provide a valid email");
	    emailText.addValidator(ev);
	    layout.addComponent(emailText);

	    FieldGroup fieldGroup = new FieldGroup(myfields);
	    fieldGroup.bind(nameText, "name");
	    fieldGroup.bind(ageText, "age");
	    fieldGroup.bind(emailText, "email");

	    Button button = new Button("Submit");
	    button.addClickListener(new Button.ClickListener()
	    {
	      public void buttonClick(ClickEvent event)
	      {
	        Boolean failed = false;
	        errLabel.setValue("");
	        try
	        {
	          nameText.validate();
	        }
	        catch (InvalidValueException e)
	        {
	          errLabel.setValue(" - " + e.getMessage());
	          nameText.setValidationVisible(true);
	          failed = true;
	        }

	        try
	        {
	          ageText.validate();
	        }
	        catch (Exception e)
	        {
	          errLabel.setValue(errLabel.getValue() + " - " + e.getMessage());
	          ageText.setValidationVisible(true);
	          failed = true;
	        }

	        try
	        {
	          emailText.validate();
	        }
	        catch (InvalidValueException e)
	        {
	          String emsg = e.getMessage();
	          if(emsg == "")
	          {
	            emsg = "email is required";
	          }
	          errLabel.setValue(errLabel.getValue() + " - " + emsg);
	          failed = true;
	        }

	        if (!failed)
	        {
	          Notification.show("Everythig is OK !", Notification.Type.TRAY_NOTIFICATION);
	        }
	      }
	    });
	    layout.addComponent(button);
	    layout.addComponent(errLabel);
	  }
}